summaryrefslogtreecommitdiffstats
path: root/setup.py
diff options
context:
space:
mode:
authorThomas Waldmann <tw@waldmann-edv.de>2020-10-10 23:12:47 +0200
committerThomas Waldmann <tw@waldmann-edv.de>2020-10-31 22:04:44 +0100
commit49b142168276d8b8a74f419d75a480fb22557a9f (patch)
tree8b4e8108b40d6e67e051030904b464aeae315c71 /setup.py
parentd56c816cf25863f5a57e82d2f422f138774391f9 (diff)
FUSE: support pyfuse3 additionally to llfuse, fixes #5407
FUSE implementation can be switched via env var BORG_FUSE_IMPL.
Diffstat (limited to 'setup.py')
-rw-r--r--setup.py15
1 files changed, 9 insertions, 6 deletions
diff --git a/setup.py b/setup.py
index e19159c8c..4152f9da2 100644
--- a/setup.py
+++ b/setup.py
@@ -78,14 +78,17 @@ install_requires = [
]
# note for package maintainers: if you package borgbackup for distribution,
# please add llfuse as a *requirement* on all platforms that have a working
# llfuse package. "borg mount" needs llfuse to work.
# if you do not have llfuse, do not require it, most of borgbackup will work.
extras_require = {
- 'fuse': [
- 'llfuse >=1.3.4, <1.3.7; python_version <"3.9"', # broken on py39
- 'llfuse >=1.3.7, <2.0; python_version >="3.9"', # broken on freebsd
+ 'llfuse': [
+ 'llfuse >= 1.3.8',
],
+ 'pyfuse3': [
+ 'pyfuse3 >= 3.1.1',
+ ],
+ 'nofuse': [],
}
compress_source = 'src/borg/compress.pyx'
@@ -78,14 +78,17 @@ install_requires = [
]
# note for package maintainers: if you package borgbackup for distribution,
-# please add llfuse as a *requirement* on all platforms that have a working
-# llfuse package. "borg mount" needs llfuse to work.
-# if you do not have llfuse, do not require it, most of borgbackup will work.
+# please (if available) add pyfuse3 (preferably) or llfuse (not maintained any more)
+# as a *requirement*. "borg mount" needs one of them to work.
+# if neither is available, do not require it, most of borgbackup will work.
extras_require = {